<?php namespace EwCacheInvalidator;

use EwCacheInvalidator\PageQueries;
use EwCacheInvalidator\DataStorage;
use EwCacheInvalidator\Lcc;

/**
 * Class PageSettings
 * @package EwCacheInvalidator
 */
class PageSettings {

    /**
     * PageSettings constructor.
     */
    public function __construct() {

        add_action('admin_enqueue_scripts', function() {

            if(isset($_GET['page']) && $_GET['page'] === 'ew-cache-invalidator') {
                wp_enqueue_script('ew-cache-invalidator-settings-page', plugins_url('../src/assets/js/admin.js', __FILE__));
                wp_register_style('ew-cache-invalidator-admin-style', plugins_url('../src/assets/css/admin.css', __FILE__));
                wp_enqueue_style('ew-cache-invalidator-admin-style' );
            }
        });
    }

    /**
     * Render the admin page.
     */
    public function renderAdminPage() {

        print '<h1>Cache invalidation settings</h1>';

        print '<h3>Run query lookup</h3>';
        print '<p><input type="button" value="Find all queries" class="button button-primary" id="reset-all-queries-btn" /></p>';
        print '<p class="progress-indicator-reset-all-queries"></p>';
        print '<p class="description">This action removes all existing queries before adding.</p>';
    }

    /**
     * Reset all queries via ajax.
     */
    public static function ajaxResetAllQueries() {
        $status = self::resetAllQueries();

        wp_send_json([
            'status' => $status
        ]);

        die();
    }

    /**
     * Reset all queries.
     *
     * @return bool
     */
    private static function resetAllQueries() {

        $pageQueries = new PageQueries();
        $dataStorage = new DataStorage();
        $lcc = new Lcc();

        $success = $dataStorage->purgeTable();
        // TODO: Deregister all listeners as well.
        if($success) {

            $queryArr = $pageQueries->getAllQueries();

            foreach($queryArr as $query) {

                if(is_array($query) && count($query) >= 3) {

                    // TODO: Move this out to own function.
                    $listener_id = $lcc->registerListener();
                    if($listener_id !== false) {
                        $dataStorage->saveItem(new QueryItem($query[0], $query[1], $query[2], $listener_id));
                    }
                }
            }

            return true;
        }

        return false;
    }

    /**
     * Check if we should listen to events.w
     *
     * @return bool
     */
    public static function checkQueryEventsActive() {
        return true;
    }
}